from database import firebase


def main():
    print("Benvenuto! Inserisci il tuo nome utente per incrementare il contatore delle visite.")
    username = input("Nome Utente: ")
    firebase.initialize_firebase()
    if firebase.increment_counter(username):
        print(f"Contatore delle visite per {username} è stato incrementato con successo {firebase.get_counter(username)}")

    else:
        print(f"Errore durante l'incremento del contatore per {username}.")


if __name__ == "__main__":
    main()


import os
import pytest
from database import firebase
import firebase_admin
from firebase_admin import db, credentials


@pytest.fixture
def firebase_initialized():
    firebase.initialize_firebase()
    yield


# Test per connessione
def test_firebase_connection(firebase_initialized):
    assert True


from database import firebase
from firebase_admin import db, credentials

firebase.initialize_firebase()
def test_right_counter():
    # Inizializza il valore del contatore a un valore specifico (ad esempio, 5)
    username_counter = db.reference('users/utente_prova').child('counter').get()

    # Verifica se il valore del contatore è stato incrementato correttamente
    assert username_counter == 10


# Test per incremento
def test_increment_counter():
    # Inizializza il valore del contatore a un valore specifico (ad esempio, 5)
    username_ref = db.reference('users/damiano')
    username_ref.child('counter').set(5)

    # Verifica se la funzione restituisce True (operazione riuscita)
    assert firebase.increment_counter('damiano') == True

    # Verifica se il valore del contatore è stato incrementato correttamente
    assert username_ref.child('counter').get() == 6  # 5 (valore iniziale) + 1 = 6



import os
import firebase_admin
from firebase_admin import credentials
from firebase_admin import db


def initialize_firebase():
    script_dir = os.path.dirname(os.path.abspath(__file__))
    config_file_path = os.path.join(script_dir, 'config.json')
    cred = credentials.Certificate(config_file_path)
    firebase_admin.initialize_app(cred, {
        'databaseURL': 'https://stassignment-swdev-default-rtdb.europe-west1.firebasedatabase.app/'
    })


def get_counter(name):
    try:
        username_ref = db.reference('users/' + name)
        return username_ref.child('counter').get()
    except Exception:
        return -1


def increment_counter(name):
    try:
        username_ref = db.reference('users/' + name)
        username_ref.child('counter').transaction(lambda current_value: current_value + 1 if current_value else 1)
        return True
    except Exception:
        return False



from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name='2023_assignment1_viewscounter',
    version='0.0.8',
    description='Questo assignment si concentra sulla creazione di un\'applicazione che conta e monitora le visualizzazioni degli utenti',
    author='Team CED',
    author_email='damianoficara@gmail.com,c.ricci19@campus.unimib.it,emiliotoli21@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown',  
    license='MIT',
    packages=find_packages(exclude=["tests"]),
    zip_safe=False
)
